@@ -9,33 +9,33 @@
    ##################################################################### */
 									/*}}}*/
 // Include Files							/*{{{*/
-#include<config.h>
+#include <config.h>
 
 #include <apt-pkg/cmndline.h>
+#include <apt-pkg/configuration.h>
 #include <apt-pkg/error.h>
 #include <apt-pkg/init.h>
 #include <apt-pkg/pkgsystem.h>
 #include <apt-pkg/strutl.h>
-#include <apt-pkg/configuration.h>
 
-#include <apt-private/private-list.h>
-#include <apt-private/private-search.h>
-#include <apt-private/private-install.h>
-#include <apt-private/private-output.h>
-#include <apt-private/private-update.h>
 #include <apt-private/private-cmndline.h>
-#include <apt-private/private-moo.h>
-#include <apt-private/private-upgrade.h>
-#include <apt-private/private-show.h>
-#include <apt-private/private-main.h>
-#include <apt-private/private-sources.h>
-#include <apt-private/private-source.h>
 #include <apt-private/private-depends.h>
 #include <apt-private/private-download.h>
+#include <apt-private/private-install.h>
+#include <apt-private/private-list.h>
+#include <apt-private/private-main.h>
+#include <apt-private/private-moo.h>
+#include <apt-private/private-output.h>
+#include <apt-private/private-search.h>
+#include <apt-private/private-show.h>
+#include <apt-private/private-source.h>
+#include <apt-private/private-sources.h>
+#include <apt-private/private-update.h>
+#include <apt-private/private-upgrade.h>
 
-#include <unistd.h>
 #include <iostream>
 #include <vector>
+#include <unistd.h>
 
 #include <apti18n.h>
 									/*}}}*/
@@ -63,9 +63,11 @@ static std::vector<aptDispatchWithHelp> GetCommands()			/*{{{*/
 
       // package stuff
       {"install", &DoInstall, _("install packages")},
+      {"reinstall", &DoInstall, _("reinstall packages")},
       {"remove", &DoInstall, _("remove packages")},
       {"autoremove", &DoInstall, _("Remove automatically all unused packages")},
       {"auto-remove", &DoInstall, nullptr},
+      {"autopurge",&DoInstall, nullptr},
       {"purge", &DoInstall, nullptr},
 
       // system wide stuff
@@ -90,6 +92,7 @@ static std::vector<aptDispatchWithHelp> GetCommands()			/*{{{*/
       {"source", &DoSource, nullptr},
       {"download", &DoDownload, nullptr},
       {"changelog", &DoChangelog, nullptr},
+      {"info", &ShowPackage, nullptr},
 
       {nullptr, nullptr, nullptr}
    };
